=======================
icalendar documentation
=======================

icalendar is an Internet Calendaring and Scheduling (iCalendar) Python package.

icalendar is an :RFC:`5545` compatible parser and generator for iCalendar files.
icalendar lets you create, inspect, and modify calendaring information with Python.

.. grid:: 1 1 2 2
    :gutter: 3 3 4 5

    .. grid-item-card::
        :link: how-to/index
        :link-type: doc

        :octicon:`zap;1.5em;sd-text-info`
        Get started
        ^^^
        This part of the documentation describes how to get started with icalendar, including how to install and use.
        +++

        .. button-ref:: how-to/index
            :color: primary
            :expand:

            Go to How to guides

    .. grid-item-card::
        :link: reference/index
        :link-type: doc

        :octicon:`bookmark;1.5em;sd-text-info`
        Reference guide
        ^^^
        This part of the documentation is a reference guide, including API, design architecture, and change log.
        +++

        .. button-ref:: reference/index
            :ref-type: doc
            :color: primary
            :expand:

            Go to Reference guide

    .. grid-item-card::
        :link: contribute/index
        :link-type: doc

        :octicon:`bookmark;1.5em;sd-text-info`
        Contributing guide
        ^^^
        This part of the documentation describes how to contribute to icalendar.
        +++

        .. button-ref:: contribute/index
            :ref-type: doc
            :color: primary
            :expand:

            Go to Contributing guide

.. toctree::
    :caption: How to guides
    :maxdepth: 2
    :hidden:

    how-to/index

.. toctree::
    :caption: Reference
    :hidden:

    reference/index

.. toctree::
    :caption: Contribute
    :hidden:

    contribute/index

-   :doc:`reference/glossary`
-   :ref:`genindex`

License
-------
See `LICENSE.rst <https://github.com/collective/icalendar/blob/main/LICENSE.rst>`_.
